==> maven-javadoc-plugin_2.5.orig.tar.gz: maven-javadoc-plugin-2.5/src/test/java/org/apache/maven/plugin/javadoc/stubs/SettingsStub.java <==
package org.apache.maven.plugin.javadoc.stubs;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.util.Collections;
import java.util.List;

import org.apache.maven.settings.Proxy;
import org.apache.maven.settings.Settings;

/**
 * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
 * @version $Id: SettingsStub.java 583461 2007-10-10 13:03:20Z vsiveton $
 */
public class SettingsStub
    extends Settings
{
    /**
     * @see org.apache.maven.settings.Settings#getActiveProxy()
     */
    public synchronized Proxy getActiveProxy()
    {
        Proxy proxy = new Proxy();
        proxy.setActive( true );
        proxy.setHost( "http://localhost" );
        proxy.setPort( 80 );
        proxy.setUsername( "toto" );
        proxy.setPassword( "toto" );
        proxy.setNonProxyHosts( "www.google.com|*.somewhere.com" );

        return proxy;
    }

    /**
     * @see org.apache.maven.settings.Settings#getProxies()
     */
    public List getProxies()
    {
        return Collections.singletonList( getActiveProxy() );
    }
}

==> maven-javadoc-plugin_2.6.1.orig.tar.gz: maven-javadoc-plugin-2.6.1/src/test/java/org/apache/maven/plugin/javadoc/stubs/SettingsStub.java <==
package org.apache.maven.plugin.javadoc.stubs;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.util.Collections;
import java.util.List;

import org.apache.maven.settings.Proxy;
import org.apache.maven.settings.Settings;

/**
 * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
 * @version $Id: SettingsStub.java 791101 2009-07-04 10:58:24Z vsiveton $
 */
public class SettingsStub
    extends Settings
{
    /** {@inheritDoc} */
    public synchronized Proxy getActiveProxy()
    {
        Proxy proxy = new Proxy();
        proxy.setActive( true );
        proxy.setHost( "http://localhost" );
        proxy.setPort( 80 );
        proxy.setUsername( "toto" );
        proxy.setPassword( "toto" );
        proxy.setNonProxyHosts( "www.google.com|*.somewhere.com" );

        return proxy;
    }

    /** {@inheritDoc} */
    public List getProxies()
    {
        return Collections.singletonList( getActiveProxy() );
    }
}
